==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebBaseToolbarColumnActionsDirectiveDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebGridToolbarBaseActionDescription } from "./WebGridToolbarBaseActionDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebBaseToolbarColumnActionsDirectiveDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebBaseToolbarColumnActionsDirectiveDescription, _super);
    function WebBaseToolbarColumnActionsDirectiveDescription() {
        var _this = _super.call(this) || this;
        _this.i = null;
        return _this;
    }
    WebBaseToolbarColumnActionsDirectiveDescription.prototype.get_type = function () {
        return "WebBaseToolbarColumnActionsDirective";
    };
    Object.defineProperty(WebBaseToolbarColumnActionsDirectiveDescription.prototype, "name", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.e("Name");
        },
        enumerable: false,
        configurable: true
    });
    WebBaseToolbarColumnActionsDirectiveDescription.$t = markType(WebBaseToolbarColumnActionsDirectiveDescription, 'WebBaseToolbarColumnActionsDirectiveDescription', WebGridToolbarBaseActionDescription.$);
    return WebBaseToolbarColumnActionsDirectiveDescription;
}(WebGridToolbarBaseActionDescription));
export { WebBaseToolbarColumnActionsDirectiveDescription };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebBaseToolbarColumnActionsDirectiveDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebBaseToolbarDirectiveDescription } from "./WebBaseToolbarDirectiveDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebBaseToolbarColumnActionsDirectiveDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebBaseToolbarColumnActionsDirectiveDescription, _super);
    function WebBaseToolbarColumnActionsDirectiveDescription() {
        var _this = _super.call(this) || this;
        _this.ac = null;
        return _this;
    }
    WebBaseToolbarColumnActionsDirectiveDescription.prototype.get_type = function () {
        return "WebBaseToolbarColumnActionsDirective";
    };
    Object.defineProperty(WebBaseToolbarColumnActionsDirectiveDescription.prototype, "name", {
        get: function () {
            return this.ac;
        },
        set: function (a) {
            this.ac = a;
            this.e("Name");
        },
        enumerable: false,
        configurable: true
    });
    WebBaseToolbarColumnActionsDirectiveDescription.$t = markType(WebBaseToolbarColumnActionsDirectiveDescription, 'WebBaseToolbarColumnActionsDirectiveDescription', WebBaseToolbarDirectiveDescription.$);
    return WebBaseToolbarColumnActionsDirectiveDescription;
}(WebBaseToolbarDirectiveDescription));
export { WebBaseToolbarColumnActionsDirectiveDescription };
